==> mtc-starter-web-1.0.0-sources.jar: cool/mtc/web/result/GlobalResultWrapper.java <==
package cool.mtc.web.result;

import com.fasterxml.jackson.databind.ObjectMapper;
import cool.mtc.core.exception.CustomException;
import cool.mtc.core.result.Result;
import cool.mtc.core.result.ResultConstant;
import cool.mtc.core.util.StringUtil;
import cool.mtc.web.WebProperties;
import cool.mtc.web.component.I18nHandler;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.MethodParameter;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.server.ServerHttpRequest;
import org.springframework.http.server.ServerHttpResponse;
import org.springframework.validation.BindException;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.mvc.method.annotation.ResponseBodyAdvice;

import java.util.HashSet;
import java.util.Set;

/**
 * @author 明河
 */
@Slf4j
@RestControllerAdvice
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class GlobalResultWrapper implements ResponseBodyAdvice<Object> {
    private static final ObjectMapper MAPPER = new ObjectMapper();
    private static final Set<String> SUPPORT_PACKAGE_SET = new HashSet<>();
    private static final Set<String> UN_SUPPORT_PACKAGE_SET = new HashSet<>();

    private final WebProperties webProperties;
    private final I18nHandler i18nHandler;

    @Override
    public boolean supports(MethodParameter returnType, Class<? extends HttpMessageConverter<?>> converterType) {
        String[] basePackages = webProperties.getGlobalResultWrapperBasePackages();
        if (null == basePackages || basePackages.length == 0) {
            return true;
        }
        String packageName = returnType.getDeclaringClass().getPackage().getName();
        if (SUPPORT_PACKAGE_SET.contains(packageName)) {
            return true;
        }
        if (UN_SUPPORT_PACKAGE_SET.contains(packageName)) {
            return false;
        }
        for (String basePackage : basePackages) {
            if (packageName.startsWith(basePackage)) {
                SUPPORT_PACKAGE_SET.add(packageName);
                return true;
            }
        }
        UN_SUPPORT_PACKAGE_SET.add(packageName);
        return false;
    }

    @SneakyThrows
    @Override
    public Object beforeBodyWrite(Object body, MethodParameter returnType, MediaType selectedContentType, Class<? extends HttpMessageConverter<?>> selectedConverterType, ServerHttpRequest request, ServerHttpResponse response) {
        response.getHeaders().setContentType(MediaType.APPLICATION_JSON);
        return body instanceof Result ? body : Result.ofData(body);
    }

    @ExceptionHandler(value = CustomException.class)
    public Result<Object> handleException(CustomException ex) {
        return this.handleExceptionAndPrintLog(ex, ex.getResult());
    }

    @ExceptionHandler(value = Exception.class)
    public Result<Object> handleException(Exception ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.ERROR);
    }

    @ExceptionHandler(value = BindException.class)
    public Result<Object> handleException(BindException ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.A0400.newInstance().msg(this.getErrorMsg(ex.getBindingResult())));
    }

    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public Result<Object> handleException(MethodArgumentNotValidException ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.A0400.newInstance().msg(this.getErrorMsg(ex.getBindingResult())));
    }

    @ExceptionHandler(value = MissingServletRequestParameterException.class)
    public Result<Object> handleException(MissingServletRequestParameterException ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.A0400.newInstance().msg("request.param.required").args(ex.getParameterName()));
    }

    private String getErrorMsg(BindingResult bindingResult) {
        return bindingResult.hasErrors() ? bindingResult.getAllErrors().get(0).getDefaultMessage() : StringUtil.EMPTY;
    }

    private Result<Object> handleExceptionAndPrintLog(Exception ex, Result<Object> result) {
        result.setMsg(i18nHandler.getMessage(result.getMsg(), result.getArgs()));
        this.printLog(ex, result);
        return result;
    }

    /**
     * 打印日志
     */
    private <T> void printLog(Exception ex, Result<T> result) {
        String logContent = String.format("%s（%s-%s）", ex.getClass().toString(), result.getCode(), result.getMsg());
        log.error(logContent, ex);
    }
}

==> mtc-starter-web-1.0.6-sources.jar: cool/mtc/web/result/GlobalResultWrapper.java <==
package cool.mtc.web.result;

import com.fasterxml.jackson.databind.ObjectMapper;
import cool.mtc.core.exception.CustomException;
import cool.mtc.core.result.Result;
import cool.mtc.core.result.ResultConstant;
import cool.mtc.core.util.StringUtil;
import cool.mtc.web.WebProperties;
import cool.mtc.web.component.I18nHandler;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.MethodParameter;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.server.ServerHttpRequest;
import org.springframework.http.server.ServerHttpResponse;
import org.springframework.validation.BindException;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.mvc.method.annotation.ResponseBodyAdvice;

import java.util.HashSet;
import java.util.Set;

/**
 * @author 明河
 */
@Slf4j
@RestControllerAdvice
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class GlobalResultWrapper implements ResponseBodyAdvice<Object> {
    private static final ObjectMapper MAPPER = new ObjectMapper();
    private static final Set<String> SUPPORT_PACKAGE_SET = new HashSet<>();
    private static final Set<String> UN_SUPPORT_PACKAGE_SET = new HashSet<>();

    private final WebProperties webProperties;
    private final I18nHandler i18nHandler;

    @Override
    public boolean supports(MethodParameter returnType, Class<? extends HttpMessageConverter<?>> converterType) {
        String[] basePackages = webProperties.getGlobalResultWrapperBasePackages();
        if (null == basePackages || basePackages.length == 0) {
            return true;
        }
        String packageName = returnType.getDeclaringClass().getPackage().getName();
        if (SUPPORT_PACKAGE_SET.contains(packageName)) {
            return true;
        }
        if (UN_SUPPORT_PACKAGE_SET.contains(packageName)) {
            return false;
        }
        for (String basePackage : basePackages) {
            if (packageName.startsWith(basePackage)) {
                SUPPORT_PACKAGE_SET.add(packageName);
                return true;
            }
        }
        UN_SUPPORT_PACKAGE_SET.add(packageName);
        return false;
    }

    @SneakyThrows
    @Override
    public Object beforeBodyWrite(Object body, MethodParameter returnType, MediaType selectedContentType, Class<? extends HttpMessageConverter<?>> selectedConverterType, ServerHttpRequest request, ServerHttpResponse response) {
        response.getHeaders().setContentType(MediaType.APPLICATION_JSON);
        return body instanceof Result ? body : Result.ofData(body);
    }

    @ExceptionHandler(value = CustomException.class)
    public Result<Object> handleException(CustomException ex) {
        return this.handleExceptionAndPrintLog(ex, ex.getResult());
    }

    @ExceptionHandler(value = Exception.class)
    public Result<Object> handleException(Exception ex) {
        Result<Object> result = ResultConstant.ERROR.newInstance();
        if (webProperties.getShowExceptionDetail()) {
            result.msg(ex.toString());
        }
        return this.handleExceptionAndPrintLog(ex, result);
    }

    @ExceptionHandler(value = BindException.class)
    public Result<Object> handleException(BindException ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.A0400.newInstance().msg(this.getErrorMsg(ex.getBindingResult())));
    }

    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public Result<Object> handleException(MethodArgumentNotValidException ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.A0400.newInstance().msg(this.getErrorMsg(ex.getBindingResult())));
    }

    @ExceptionHandler(value = MissingServletRequestParameterException.class)
    public Result<Object> handleException(MissingServletRequestParameterException ex) {
        return this.handleExceptionAndPrintLog(ex, ResultConstant.A0400.newInstance().msg("request.param.required").args(ex.getParameterName()));
    }

    private String getErrorMsg(BindingResult bindingResult) {
        return bindingResult.hasErrors() ? bindingResult.getAllErrors().get(0).getDefaultMessage() : StringUtil.EMPTY;
    }

    private Result<Object> handleExceptionAndPrintLog(Exception ex, Result<Object> result) {
        result.setMsg(i18nHandler.getMessage(result.getMsg(), result.getArgs()));
        this.printLog(ex, result);
        return result;
    }

    /**
     * 打印日志
     */
    private <T> void printLog(Exception ex, Result<T> result) {
        String logContent = String.format("%s（%s-%s）", ex.getClass().toString(), result.getCode(), result.getMsg());
        log.error(logContent, ex);
    }
}
